Drinfeld modules
====================================

SageMath include facilities to manipulate Drinfeld modules and their morphisms. The
main entry point is the class
:class:`sage.rings.function_field.drinfeld_modules.drinfeld_module.DrinfeldModule`.

Drinfeld modules
----------------

.. toctree::
   :maxdepth: 2

   sage/rings/function_field/drinfeld_modules/drinfeld_module
   sage/rings/function_field/drinfeld_modules/charzero_drinfeld_module
   sage/rings/function_field/drinfeld_modules/finite_drinfeld_module

Morphisms and isogenies
-----------------------

.. toctree::
   :maxdepth: 2

   sage/rings/function_field/drinfeld_modules/morphism
   sage/rings/function_field/drinfeld_modules/homset

The module action induced by a Drinfeld module
----------------------------------------------

.. toctree::
   :maxdepth: 2

   sage/rings/function_field/drinfeld_modules/action

The category of Drinfeld modules
--------------------------------

.. toctree::
   :maxdepth: 2

   sage/categories/drinfeld_modules

.. include:: ../footer.txt
